# napari_vodex: A napari plugin for VoDEx.

A graphical interface for vodex is available as a napari plugin: [napari-vodex](https://www.napari-hub.org/plugins/napari-vodex#installation).
It allows to create experimental annotation without any coding and to load volumetric data directly into napari viewer.

napari-vodex is written  using PyQt and the source code is available at [LemonJust/napari-vodex](https://github.com/LemonJust/napari-vodex)


[![License BSD-3](https://img.shields.io/pypi/l/napari-vodex.svg?color=green)](https://github.com/LemonJust/napari-vodex/raw/main/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/napari-vodex.svg?color=green)](https://pypi.org/project/napari-vodex)
[![Python Version](https://img.shields.io/pypi/pyversions/napari-vodex.svg?color=green)](https://python.org)
[![tests](https://github.com/LemonJust/napari-vodex/workflows/tests/badge.svg)](https://github.com/LemonJust/napari-vodex/actions)
[![codecov](https://codecov.io/gh/LemonJust/napari-vodex/branch/main/graph/badge.svg)](https://codecov.io/gh/LemonJust/napari-vodex)
[![napari hub](https://img.shields.io/endpoint?url=https://api.napari-hub.org/shields/napari-vodex)](https://napari-hub.org/plugins/napari-vodex)

## Installation

You can install `napari-vodex` via [pip]:

    pip install napari-vodex

Or through napari plugin manager.

## Usage

To get started with `napari_vodex` plugin,
please see details and examples in [Usage](https://lemonjust.github.io/vodex/napari/how-to/).
